@@ -4,13 +4,12 @@
 
 # config
 
-from qcodes.config import Config
-from qcodes.logger import start_all_logging
+import qcodes.configuration as qcconfig
 from qcodes.logger.logger import conditionally_start_all_logging
 from qcodes.utils.helpers import add_to_spyder_UMR_excludelist
 from .version import __version__
 
-config: Config = Config()
+config: qcconfig.Config = qcconfig.Config()
 
 conditionally_start_all_logging()
 
@@ -18,31 +17,38 @@ conditionally_start_all_logging()
 # instrument list and running monitor
 add_to_spyder_UMR_excludelist('qcodes')
 
-
 from qcodes.version import __version__
 
-plotlib = config.gui.plotlib
-if plotlib in {'QT', 'all'}:
-    try:
-        from qcodes.plots.pyqtgraph import QtPlot
-    except Exception:
-        print('pyqtgraph plotting not supported, '
-              'try "from qcodes.plots.pyqtgraph import QtPlot" '
-              'to see the full error')
+if config.core.import_legacy_api:
+    plotlib = config.gui.plotlib
+    if plotlib in {'QT', 'all'}:
+        try:
+            from qcodes.plots.pyqtgraph import QtPlot
+        except Exception:
+            print('pyqtgraph plotting not supported, '
+                  'try "from qcodes.plots.pyqtgraph import QtPlot" '
+                  'to see the full error')
 
-if plotlib in {'matplotlib', 'all'}:
-    try:
-        from qcodes.plots.qcmatplotlib import MatPlot
-    except Exception:
-        print('matplotlib plotting not supported, '
-              'try "from qcodes.plots.qcmatplotlib import MatPlot" '
-              'to see the full error')
+    if plotlib in {'matplotlib', 'all'}:
+        try:
+            from qcodes.plots.qcmatplotlib import MatPlot
+        except Exception:
+            print('matplotlib plotting not supported, '
+                  'try "from qcodes.plots.qcmatplotlib import MatPlot" '
+                  'to see the full error')
+    from qcodes.loops import Loop, active_loop, active_data_set
+    from qcodes.measure import Measure
+    from qcodes.data.data_set import DataSet, new_data, load_data
+    from qcodes.actions import Task, Wait, BreakIf
+    from qcodes.data.location import FormatLocation
+    from qcodes.data.data_array import DataArray
+    from qcodes.data.format import Formatter
+    from qcodes.data.gnuplot_format import GNUPlotFormat
+    from qcodes.data.hdf5_format import HDF5Format
+    from qcodes.data.io import DiskIO
 
 
 from qcodes.station import Station
-from qcodes.loops import Loop, active_loop, active_data_set
-from qcodes.measure import Measure
-from qcodes.actions import Task, Wait, BreakIf
 haswebsockets = True
 try:
     import websockets
@@ -51,19 +57,13 @@ except ImportError:
 if haswebsockets:
     from qcodes.monitor.monitor import Monitor
 
-from qcodes.data.data_set import DataSet, new_data, load_data
-from qcodes.data.location import FormatLocation
-from qcodes.data.data_array import DataArray
-from qcodes.data.format import Formatter
-from qcodes.data.gnuplot_format import GNUPlotFormat
-from qcodes.data.hdf5_format import HDF5Format
-from qcodes.data.io import DiskIO
+
+
 
 from qcodes.instrument.base import Instrument, find_or_create_instrument
 from qcodes.instrument.ip import IPInstrument
 from qcodes.instrument.visa import VisaInstrument
 from qcodes.instrument.channel import InstrumentChannel, ChannelList
-
 from qcodes.instrument.function import Function
 from qcodes.instrument.parameter import (
     Parameter,
@@ -78,7 +78,6 @@ from qcodes.instrument.parameter import (
 from qcodes.instrument.sweep_values import SweepFixedValues, SweepValues
 
 from qcodes.utils import validators
-from qcodes.utils.zmq_helpers import Publisher
 
 from qcodes.instrument_drivers.test import test_instruments, test_instrument
 
@@ -108,7 +107,6 @@ import logging
 # ensure to close all instruments when interpreter is closed
 import atexit
 atexit.register(Instrument.close_all)
-atexit.register(logging.shutdown)
 
 
 def test(**kwargs):
@@ -119,8 +117,10 @@ def test(**kwargs):
     """
     try:
         import pytest
+        from hypothesis import settings
+        settings(deadline=1000)
     except ImportError:
-        print("Need pytest to run tests")
+        print("Need pytest and hypothesis to run tests")
         return
     args = ['--pyargs', 'qcodes.tests']
     retcode = pytest.main(args, **kwargs)
