@@ -168,35 +168,53 @@ def get_parameter_data(conn: ConnectionPlus,
         start: start of range; if None, then starts from the top of the table
         end: end of range; if None, then ends at the bottom of the table
     """
-    interdeps = get_interdeps_from_result_table_name(conn, table_name)
+    rundescriber = get_rundescriber_from_result_table_name(conn, table_name)
 
     output = {}
     if len(columns) == 0:
-        columns = [ps.name for ps in interdeps.non_dependencies]
+        columns = [ps.name for ps in rundescriber.interdeps.non_dependencies]
 
     # loop over all the requested parameters
     for output_param in columns:
-        one_param_output, _ = get_parameter_data_for_one_paramtree(conn, table_name, interdeps, output_param, start, end)
+        one_param_output, _ = get_parameter_data_for_one_paramtree(conn, table_name, rundescriber, output_param, start, end)
         output[output_param] = one_param_output
     return output
 
 
-def get_interdeps_from_result_table_name(conn: ConnectionPlus, result_table_name: str) -> InterDependencies_:
+def get_rundescriber_from_result_table_name(
+        conn: ConnectionPlus,
+        result_table_name: str
+) -> RunDescriber:
     sql = """
     SELECT run_id FROM runs WHERE result_table_name = ?
     """
     c = atomic_transaction(conn, sql, result_table_name)
     run_id = one(c, 'run_id')
     rd = serial.from_json_to_current(get_run_description(conn, run_id))
+    return rd
+
+
+def get_interdeps_from_result_table_name(conn: ConnectionPlus, result_table_name: str) -> InterDependencies_:
+    rd = get_rundescriber_from_result_table_name(conn, result_table_name)
     interdeps = rd.interdeps
     return interdeps
 
 
-def get_parameter_data_for_one_paramtree(conn: ConnectionPlus, table_name: str, interdeps: InterDependencies_,
-                                         output_param: str, start: Optional[int], end: Optional[int]) -> Tuple[Dict[str, np.ndarray], int]:
-    data, paramspecs, n_rows = _get_data_for_one_param_tree(conn, table_name, interdeps, output_param, start, end)
+def get_parameter_data_for_one_paramtree(
+        conn: ConnectionPlus,
+        table_name: str,
+        rundescriber: RunDescriber,
+        output_param: str,
+        start: Optional[int],
+        end: Optional[int]
+) -> Tuple[Dict[str, np.ndarray], int]:
+    interdeps = rundescriber.interdeps
+    data, paramspecs, n_rows = _get_data_for_one_param_tree(
+        conn, table_name, interdeps, output_param, start, end
+    )
     if not paramspecs[0].name == output_param:
-        raise ValueError("output_param should always be the first parameter in a parameter tree. It is not")
+        raise ValueError("output_param should always be the first "
+                         "parameter in a parameter tree. It is not")
     _expand_data_to_arrays(data, paramspecs)
     # Benchmarking shows that transposing the data with python types is
     # faster than transposing the data using np.array.transpose
