@@ -97,7 +97,7 @@ class InstrumentBase(Metadatable, DelegateAttributes):
                 name.
         """
         if name in self.parameters:
-            raise KeyError('Duplicate parameter name {}'.format(name))
+            raise KeyError(f'Duplicate parameter name {name}')
         param = parameter_class(name=name, instrument=self, **kwargs)
         self.parameters[name] = param
 
@@ -125,7 +125,7 @@ class InstrumentBase(Metadatable, DelegateAttributes):
                 name.
         """
         if name in self.functions:
-            raise KeyError('Duplicate function name {}'.format(name))
+            raise KeyError(f'Duplicate function name {name}')
         func = Function(name=name, instrument=self, **kwargs)
         self.functions[name] = func
 
@@ -158,7 +158,7 @@ class InstrumentBase(Metadatable, DelegateAttributes):
                 not an instance of an ``Metadatable`` object.
         """
         if name in self.submodules:
-            raise KeyError('Duplicate submodule name {}'.format(name))
+            raise KeyError(f'Duplicate submodule name {name}')
         if not isinstance(submodule, Metadatable):
             raise TypeError('Submodules must be metadatable.')
         self.submodules[name] = submodule
@@ -266,12 +266,12 @@ class InstrumentBase(Metadatable, DelegateAttributes):
                 # this may be a multi parameter
                 unit = snapshot['parameters'][par].get('units', None)
             if isinstance(val, floating_types):
-                msg += '\t{:.5g} '.format(val)  # type: ignore[str-format]
+                msg += f'\t{val:.5g} '
                 # numpy float and int types format like builtins
             else:
-                msg += '\t{} '.format(val)
+                msg += f'\t{val} '
             if unit != '':  # corresponds to no unit
-                msg += '({})'.format(unit)
+                msg += f'({unit})'
             # Truncate the message if it is longer than max length
             if len(msg) > max_chars and not max_chars == -1:
                 msg = msg[0:max_chars-3] + '...'
@@ -386,7 +386,7 @@ class InstrumentBase(Metadatable, DelegateAttributes):
             if p.gettable and p.settable:
                 value = p.get()
                 if verbose:
-                    print('validate_status: param %s: %s' % (k, value))
+                    print(f'validate_status: param {k}: {value}')
                 p.validate(value)
 
 
@@ -560,7 +560,7 @@ class Instrument(InstrumentBase, AbstractInstrument):
         # making sure its name is unique
         existing_wr = cls._all_instruments.get(name)
         if existing_wr and existing_wr():
-            raise KeyError('Another instrument has the name: {}'.format(name))
+            raise KeyError(f'Another instrument has the name: {name}')
 
         cls._all_instruments[name] = wr
 
@@ -630,7 +630,7 @@ class Instrument(InstrumentBase, AbstractInstrument):
 
         if ins is None:
             del cls._all_instruments[name]
-            raise KeyError('Instrument {} has been removed'.format(name))
+            raise KeyError(f'Instrument {name} has been removed')
         if instrument_class is not None:
             if not isinstance(ins, instrument_class):
                 raise TypeError(
